clear variables
close all
clc

% import the ADS simulation data
simdata = ADSimportSimData('MeasuredAmplifier.mat');

% gather the impedance data in an FRM
freq = simdata.sim2_AC.freq;
data = zeros(4,1,length(freq));
data(1,1,:) = simdata.sim2_AC.base;
data(2,1,:) = simdata.sim2_AC.coll;
data(3,1,:) = simdata.sim2_AC.in;
data(4,1,:) = simdata.sim2_AC.out;
Z = FRM(data,'Freq',freq,'Normalisation',LowpassNormalisation(freq));

% gather the S-parameters in a TwoPort
S = TwoPort(simdata.sim1_S.S,'Freq',simdata.sim1_S.freq);

% project the impedance data onto stable and unstable bases
PROJ = PisaProject(Z,'Interpolation',RationalInterpolation,'EstimateInterpolationError',true);

% show the result
figure
plot(Z,'Color',[0 0.4 0],'Linewidth',2);
plot(PROJ.unstable,'Color','r','Linewidth',2);
plot(PROJ.stable  ,'Color','b','Linewidth',2);
% plot(PROJ.InterpErr  ,'Color','k','Linewidth',2);
xlim([0 max(Z.Freq)]);
ylim([-120 60])


%% now analyse the measurements

% read the measurement data into a MultiPort
Smeasured = TwoPort.read('MeasuredAmplifier.s2p');

% project the S-parameters onto stable and unstable bases
PROJmeasured = PisaProject(Smeasured,'Interpolation',LinearInterpolation);

% plot the result
figure
plot(Smeasured,'Scale','Hz','Color',[0 0.4 0],'Linewidth',2);
plot(PROJmeasured.unstable,'Scale','Hz','Color','r','Linewidth',2);
plot(PROJmeasured.stable  ,'Scale','Hz','Color','b','Linewidth',2);
xlim([min(Smeasured.Freq) max(Smeasured.Freq)])
