clear variables
close all
clc

% load the simulation data from the mat file created by ADS
simdata = ADSimportSimData('BalancedAmplifier.mat');

%% perform the analysis on a single impedance function

% we use one of the measured voltages to obtain a system with one input and one output
data = reshape(simdata.sim1_AC.coll1,1,1,[]);
freq = simdata.sim1_AC.freq;

% gather the data and frequency in an FRM
Z = FRM(data,'Freq',freq,'Normalisation',LowpassNormalisation(freq));

% call the projection method
PROJ = PisaProject(Z,'Interpolation',RationalInterpolation);

% plot the result
figure(1)
clf
plot(    Z        ,'Color',[0 0.4 0],'linewidth',2);
plot(PROJ.stable  ,'Color','b','linewidth',2);
plot(PROJ.unstable,'Color','r','linewidth',2);
xlim([0 max(Z.Freq)])
ylim([-20 60])
legend('original data','stable part','unstable part')

%% perform the analysis on all impedance functions

% we collect 4 measured voltages to create a system with one input and 4 outputs
data = reshape([simdata.sim1_AC.coll1;simdata.sim1_AC.coll2;simdata.sim1_AC.base1;simdata.sim1_AC.base2],4,1,[]);
freq = simdata.sim1_AC.freq;

% gather the data and frequency in an FRM
Z = FRM(data,'Freq',freq,'Normalisation',LowpassNormalisation(freq));

% call the projection method to determine whether the data is stable. 
% We use the rational interpolation to obtain the lowest interpolation error
PROJ = PisaProject(Z,'Interpolation',RationalInterpolation);

% plot the result
figure(2)
plot(    Z        ,'Color',[0 0.4 0],'linewidth',2);
plot(PROJ.stable  ,'Color','b','linewidth',2);
plot(PROJ.unstable,'Color','r','linewidth',2);
xlim([0 max(Z.Freq)])
ylim([-20 60])


%% Estimate the pole location

[poles,singularvalues] = PisaEstimate(Z,'Projection',PROJ,'order',2);

fprintf('poles estimated at: %g GHz\n',abs(imag(poles(1)))/2/pi/1e9);
fprintf(' with a damping of %2.2g \n',cos(pi-angle(poles(1))));

figure(3)
plot(log10(singularvalues/singularvalues(1)),'o-','linewidth',2);
xlabel('i')
ylabel('log_{10}(\sigma_i / \sigma_1)');
xlim([1 20])
grid on
