clear variables
close all
clc

% import the simulation data generated by the Large-Signal Small-Signal simulation in ADS
simdata = ADSimportSimData('LargeSignal_0.5V.mat');

% extract the Harmonic transfer functions from the imported simulation data
HTFdata=LSSSextractHTFs(simdata.sim2_LSSS,'Basis','cosine');

% gather 5 HTFs as a system with 5 outputs and one input.
% We consider HTF-2 HTF-1 HTF0 HTF+1 HTF+2 as frequency responses of the system
data = reshape(HTFdata.Vd((end-1)/2+1+(-2:2),:),5,1,[]);
freq = HTFdata.freq;

% construct an FRM object with the frequency response data
% we use a lowpass normalisation because we know the data close to DC
Z_lowamp = FRM(data,'Freq',freq,'Normalisation',LowpassNormalisation(freq));

% call the projection method with a rational interpolation and also estimate the interpolation error
PROJ_lowamp = PisaProject(Z_lowamp,'EstimateInterpolationError',true,'Interpolation',RationalInterpolation);

% show the result
figure
plot(Z_lowamp,'Scale','Hz','Color',[0 0.4 0],'linewidth',2);
plot(PROJ_lowamp.unstable,'Scale','Hz','Color','r','linewidth',2);
plot(PROJ_lowamp.stable  ,'Scale','Hz','Color','b','linewidth',2);
plot(PROJ_lowamp.InterpErr ,'Scale','Hz','Color','k','linewidth',2);
xlim([0 max(Z_lowamp.Freq)]);
ylim([-100 100])

%% Analysis for the large-signal source at 1.5V amplitude

% import the simulation data generated by the Large-Signal Small-Signal simulation in ADS
simdata = ADSimportSimData('LargeSignal_1.5V.mat');

% extract the Harmonic transfer functions from the imported simulation data
HTFdata=LSSSextractHTFs(simdata.sim2_LSSS,'Basis','cosine');

% again, we gather 5 HTFs
data = reshape(HTFdata.Vd((end-1)/2+1+(-2:2),:),5,1,[]);
freq = HTFdata.freq;

% construct the FRM object
Z_highamp = FRM(data,'Freq',freq,'Normalisation',LowpassNormalisation(freq));

% perform the projection
PROJ_highamp = PisaProject(Z_highamp,'EstimateInterpolationError',true,'Interpolation',RationalInterpolation);

% show the result
figure
plot(Z_highamp,'Scale','Hz','Color',[0 0.4 0],'linewidth',2);
plot(PROJ_highamp.unstable,'Scale','Hz','Color','r','linewidth',2);
plot(PROJ_highamp.stable  ,'Scale','Hz','Color','b','linewidth',2);
% plot(PROJ_highamp.InterpErr ,'Scale','Hz','Color','k','linewidth',1);
xlim([0 0.6e6]);
ylim([30 90])

%% estimate the unstable poles

[poles,singularvalues] = PisaEstimate(Z_highamp,'Projection',PROJ_highamp,'Order',10);

% plot the poles
figure(5)
clf
plot(poles/2/pi,'x','linewidth',2);
grid on
xlim([0 2*max(real(poles/2/pi))])
xlabel('Real part [Hz]')
ylabel('Imaginary part [Hz]')

% plot the singular values of the hankel matrix
figure(8)
clf
plot(log10(singularvalues./singularvalues(1)),'o-','linewidth',2);
grid on
xlabel('i')
ylabel('log_{10}(\sigma_i / \sigma_1)');
grid on
